package com.muyu.clw.common.saas.interceptor;

import com.muyu.clw.common.saas.contents.SaaSConstant;
import com.muyu.clw.common.saas.exception.SaaSException;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.clw.common.many.datasource.role.DynamicDataSource;
import com.muyu.common.core.utils.ServletUtils;
import com.muyu.common.core.utils.SpringUtils;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.AsyncHandlerInterceptor;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * saas数据拦截
 *
 * @ClassName SaaSInterceptor
 * @Author AnNan.Wang
 * @Date 2024/6/5 10:04
 */


public class SaaSInterceptor implements AsyncHandlerInterceptor {
    /**
     * 之前
     */
    @Override
    public boolean preHandle(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        if (!(handler instanceof HandlerMethod)) {
            return true;
        }
        String SaaSKey = ServletUtils.getHeader(request, SaaSConstant.SAAS_KEY);
        if (SaaSKey == null) {
            throw  new SaaSException("SaaS非法访问");
        }else {
            DynamicDataSource dynamicDataSource = SpringUtils.getBean(DynamicDataSource.class);
            if (!dynamicDataSource.hashKey(SaaSKey)){
                throw  new SaaSException("SaaS非法访问");
            }
        }
        DynamicDataSourceHolder.setDynamicDataSourceKey(SaaSKey);
        return true;
    }

    /**
     * 之后
     */
    @Override
    public void afterConcurrentHandlingStarted(HttpServletRequest request, HttpServletResponse response, Object handler) throws Exception {
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }
}
