package com.muyu.authentication.service.impl;

import com.muyu.authentication.mapper.AddServiceMapper;
import com.muyu.authentication.service.IAddServiceService;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.domain.AddService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 增值Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
public class AddServiceServiceImpl implements IAddServiceService
{
    @Autowired
    private AddServiceMapper addServiceMapper;

    /**
     * 查询增值
     *
     * @param id 增值主键
     * @return 增值
     */
    @Override
    public AddService selectAddServiceById(Long id)
    {
        return addServiceMapper.selectAddServiceById(id);
    }

    /**
     * 查询增值列表
     *
     * @param addService 增值
     * @return 增值
     */
    @Override
    public List<AddService> selectAddServiceList(AddService addService)
    {
        return addServiceMapper.selectAddServiceList(addService);
    }

    /**
     * 新增增值
     *
     * @param addService 增值
     * @return 结果
     */
    @Override
    public int insertAddService(AddService addService)
    {
        addService.setCreateTime(DateUtils.getNowDate());
        return addServiceMapper.insertAddService(addService);
    }

    /**
     * 修改增值
     *
     * @param addService 增值
     * @return 结果
     */
    @Override
    public int updateAddService(AddService addService)
    {
        return addServiceMapper.updateAddService(addService);
    }

    /**
     * 批量删除增值
     *
     * @param ids 需要删除的增值主键
     * @return 结果
     */
    @Override
    public int deleteAddServiceByIds(Long[] ids)
    {
        return addServiceMapper.deleteAddServiceByIds(ids);
    }

    /**
     * 删除增值信息
     *
     * @param id 增值主键
     * @return 结果
     */
    @Override
    public int deleteAddServiceById(Long id)
    {
        return addServiceMapper.deleteAddServiceById(id);
    }

    @Autowired
    private StringRedisTemplate redisTemplate;

}
