package com.muyu.authentication.service.impl;

import java.net.URI;
import java.net.http.HttpClient;
import java.net.http.HttpRequest;
import java.net.http.HttpResponse;
import java.util.Date;
import java.util.List;
import java.util.UUID;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.node.ObjectNode;
import com.muyu.authentication.mapper.EnterpriseMapper;
import com.muyu.common.core.utils.DateUtils;
import com.muyu.common.system.domain.SysUser;
import com.muyu.common.system.remote.RemoteUserService;
import com.muyu.domain.vo.EnterpriseReq;
import com.muyu.many.domain.Message.MessageData;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;
import com.muyu.domain.Enterprise;
import com.muyu.authentication.service.IEnterpriseService;

/**
 * 企业Service业务层处理
 *
 * @author wan
 * @date 2024-05-31
 */
@Service
@Log4j2
public class EnterpriseServiceImpl extends ServiceImpl<EnterpriseMapper,Enterprise> implements IEnterpriseService
{
    @Autowired
    private EnterpriseMapper enterpriseMapper;

    /**
     * 查询企业
     *
     * @param id 企业主键
     * @return 企业
     */
    @Override
    public Enterprise selectEnterpriseById(Long id)
    {
        return enterpriseMapper.selectOne(
                new LambdaQueryWrapper<>(){{
                    eq(Enterprise::getId,id);
                }}
        );
    }

    /**
     * 查询企业列表
     *
     * @param enterprise 企业
     * @return 企业
     */
    @Override
    public List<Enterprise> selectEnterpriseList(Enterprise enterprise)
    {
        return enterpriseMapper.selectEnterpriseList(enterprise);
    }

    @Autowired
    private RemoteUserService remoteUserService;
    /**
     * 新增企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    @Override
    public int insertEnterprise(Enterprise enterprise)
    {
        enterprise.setCreateTime(DateUtils.getNowDate());
        int insert = enterpriseMapper.insert(enterprise);
        if (insert>0) {
            SysUser build = SysUser.builder()
                    .userName(enterprise.getEnterpriseName())
                    .nickName(enterprise.getLegalPerson())
                    .email(enterprise.getEmail())
                    .phonenumber(enterprise.getContactPhone())
                    .password(enterprise.getContactPhone().substring(enterprise.getContactPhone().length()-6))
                    .companyId(enterprise.getId())
                    .status("0")
                    .roleId(9L)
                    .build();
            log.info(build.getPassword());
            remoteUserService.add(build);
        }
        return insert;
    }

    /**
     * 修改企业
     *
     * @param enterprise 企业
     * @return 结果
     */
    @Override
    public int updateEnterprise(Enterprise enterprise)
    {
        enterprise.setUpdateTime(DateUtils.getNowDate());
        return enterpriseMapper.updateById(enterprise);
    }

    /**
     * 批量删除企业
     *
     * @param ids 需要删除的企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseByIds(Long[] ids)
    {
        return enterpriseMapper.deleteEnterpriseByIds(ids);
    }

    /**
     * 删除企业信息
     *
     * @param id 企业主键
     * @return 结果
     */
    @Override
    public int deleteEnterpriseById(Long id)
    {
        return enterpriseMapper.deleteById(id);
    }

    @Override
    public Enterprise enterpriseList(EnterpriseReq enterpriseReq) {
        return enterpriseMapper.selectOne(
                new LambdaQueryWrapper<>(){{
                    eq(Enterprise::getLegalPerson, enterpriseReq.getLegalPerson());
                    eq(Enterprise::getContactPhone, enterpriseReq.getContactPhone());
                }}
        );
    }


    @Override
    public String enterpriseUpdate(Enterprise enterprise) {
        return enterpriseMapper.updateById(
                        Enterprise.builder()
                                .id(enterprise.getId())
                                .enterpriseName(enterprise.getEnterpriseName())
                                .legalPerson(enterprise.getLegalPerson())
                                .businessLicenseNumber(enterprise.getBusinessLicenseNumber())
                                .establishmentDate(enterprise.getEstablishmentDate())
                                .businessScope(enterprise.getBusinessScope())
                                .address(enterprise.getAddress())
                                .contactPhone(enterprise.getContactPhone())
                                .email(enterprise.getEmail())
                                .status(enterprise.getStatus())
                                .registrationDate(enterprise.getRegistrationDate())
                                .authenticationDate(enterprise.getAuthenticationDate())
                                .examineStatus(0)
                                .build()
        )>0?"提交审核成功":"提交审核失败";
    }

    @Override
    public String enterpriseUpdateId(Long id) {
        String s = enterpriseMapper.updateById(
                Enterprise.builder()
                        .id(id)
                        .authenticationDate(new Date())
                        .examineStatus(1)
                        .serviceLevel(1)
                        .openServerId("初级")
                        .build()
        ) > 0 ? "审核成功" : "审核失败";
        if (s.equals("审核成功")) {
            Enterprise enterprise = enterpriseMapper.selectOne(
                    new LambdaQueryWrapper<>() {{
                        eq(Enterprise::getId, id);
                    }}
            );
            try {
                getHttp(enterprise);
            } catch (Exception e) {
                throw new RuntimeException(e);
            }
            return s;
        }else {
            return s;
        }

    }

    @Autowired
    private RabbitTemplate rabbitTemplate;


    public void getHttp(Enterprise enterprise) throws Exception {
        // 创建HttpClient实例
        HttpClient httpClient = HttpClient.newHttpClient();

        String substring = enterprise.getContactPhone().substring(enterprise.getContactPhone().length() - 4);
        // 创建参数JSON对象
        ObjectMapper objectMapper = new ObjectMapper();
        ObjectNode requestBody = objectMapper.createObjectNode();
        requestBody.put("entId", "ent_"+substring+"_"+(3306+enterprise.getId()));
        requestBody.put("mysqlPort", 3306+enterprise.getId());
        String jsonBody = objectMapper.writeValueAsString(requestBody);

        // 创建httpRequest
        HttpRequest request = HttpRequest.newBuilder()
                .uri(URI.create("http://101.34.243.166/webhook/创建企业数据库"))
                .header("Content-Type", "application/json")
                .POST(HttpRequest.BodyPublishers.ofString(jsonBody))
                .build();

        // 发送请求并获取响应
        HttpResponse<String> response = httpClient.send(request, HttpResponse.BodyHandlers.ofString());

        // 处理响应
        int statusCode = response.statusCode();
        String responseBody = response.body();
        log.info("状态码:{}",statusCode);
        log.info("响应:{}",responseBody);


        if (statusCode == 200) {
            rabbitTemplate.convertAndSend("text1",JSON.toJSONString(enterprise),message -> {
                message.getMessageProperties().setMessageId(UUID.randomUUID().toString());
                return message;
            });

        }
    }

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Override
    public MessageData redisList(String vin) {
        String index = redisTemplate.opsForValue().get(vin);
        return JSON.parseObject(index, MessageData.class);
    }
}
