package com.muyu.many.domain;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.many.domain.req.DefectInfoQueryReq;
import com.muyu.many.domain.req.DefectInfoSaveReq;
import com.muyu.many.domain.req.DefectInfoEditReq;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 故障码对象 defect_info
 *
 * @author wan
 * @date 2024-06-20
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("defect_info")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "DefectInfo", description = "故障码")
public class DefectInfo extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 故障码 */
    @Excel(name = "故障码")
    @ApiModelProperty(name = "故障码", value = "故障码")
    private String defectCode;

    /** 故障标签 */
    @Excel(name = "故障标签")
    @ApiModelProperty(name = "故障标签", value = "故障标签")
    private String abortSituation;

    /** 故障位 */
    @Excel(name = "故障位")
    @ApiModelProperty(name = "故障位", value = "故障位")
    private Long defectBit;

    /** 故障值 */
    @Excel(name = "故障值")
    @ApiModelProperty(name = "故障值", value = "故障值")
    private Long defectValue;

    /**
    * 查询构造器
    */
    public static DefectInfo queryBuild( DefectInfoQueryReq defectInfoQueryReq){
        return DefectInfo.builder()
                .defectCode(defectInfoQueryReq.getDefectCode())
                .abortSituation(defectInfoQueryReq.getAbortSituation())
                .defectBit(defectInfoQueryReq.getDefectBit())
                .defectValue(defectInfoQueryReq.getDefectValue())
                .build();
    }

    /**
    * 添加构造器
    */
    public static DefectInfo saveBuild(DefectInfoSaveReq defectInfoSaveReq){
        return DefectInfo.builder()
                .defectCode(defectInfoSaveReq.getDefectCode())
                .abortSituation(defectInfoSaveReq.getAbortSituation())
                .defectBit(defectInfoSaveReq.getDefectBit())
                .defectValue(defectInfoSaveReq.getDefectValue())
                .build();
    }

    /**
    * 修改构造器
    */
    public static DefectInfo editBuild(Long id, DefectInfoEditReq defectInfoEditReq){
        return DefectInfo.builder()
            .id(id)
                .defectCode(defectInfoEditReq.getDefectCode())
                .abortSituation(defectInfoEditReq.getAbortSituation())
                .defectBit(defectInfoEditReq.getDefectBit())
                .defectValue(defectInfoEditReq.getDefectValue())
                .build();
    }

}
