package com.muyu.many.domain;

import java.util.Date;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.many.domain.req.FaultInfoEditReq;
import com.muyu.many.domain.req.FaultInfoQueryReq;
import com.muyu.many.domain.req.FaultInfoSaveReq;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 故障记录对象 fault_info
 *
 * @author wan
 * @date 2024-06-20
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("fault_info")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "FaultInfo", description = "故障记录")
public class FaultInfo extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 故障码 */
    @Excel(name = "故障码")
    @ApiModelProperty(name = "故障码", value = "故障码")
    private String faultCode;

    /** 车辆VIN */
    @Excel(name = "车辆VIN")
    @ApiModelProperty(name = "车辆VIN", value = "车辆VIN")
    private String vin;

    /** 故障等级 */
    @Excel(name = "故障等级")
    @ApiModelProperty(name = "故障等级", value = "故障等级")
    private String failureLevel;

    /** 故障开始时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH-mm-ss")
    @Excel(name = "故障开始时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "故障开始时间", value = "故障开始时间")
    private Date startTime;

    /** 故障结束时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH-mm-ss")
    @Excel(name = "故障结束时间", width = 30, dateFormat = "yyyy-MM-dd")
    @ApiModelProperty(name = "故障结束时间", value = "故障结束时间")
    private Date endTime;

    /**
    * 查询构造器
    */
    public static FaultInfo queryBuild( FaultInfoQueryReq faultInfoQueryReq){
        return FaultInfo.builder()
                .faultCode(faultInfoQueryReq.getFaultCode())
                .vin(faultInfoQueryReq.getVin())
                .failureLevel(faultInfoQueryReq.getFailureLevel())
                .startTime(faultInfoQueryReq.getStartTime())
                .endTime(faultInfoQueryReq.getEndTime())
                .build();
    }

    /**
    * 添加构造器
    */
    public static FaultInfo saveBuild(FaultInfoSaveReq faultInfoSaveReq){
        return FaultInfo.builder()
                .faultCode(faultInfoSaveReq.getFaultCode())
                .vin(faultInfoSaveReq.getVin())
                .failureLevel(faultInfoSaveReq.getFailureLevel())
                .startTime(faultInfoSaveReq.getStartTime())
                .endTime(faultInfoSaveReq.getEndTime())
                .build();
    }

    /**
    * 修改构造器
    */
    public static FaultInfo editBuild(Long id, FaultInfoEditReq faultInfoEditReq){
        return FaultInfo.builder()
            .id(id)
                .faultCode(faultInfoEditReq.getFaultCode())
                .vin(faultInfoEditReq.getVin())
                .failureLevel(faultInfoEditReq.getFailureLevel())
                .startTime(faultInfoEditReq.getStartTime())
                .endTime(faultInfoEditReq.getEndTime())
                .build();
    }

}
