package com.muyu.many.domain;

import java.math.BigDecimal;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.muyu.many.domain.req.FenceEditReq;
import com.muyu.many.domain.req.FenceQueryReq;
import com.muyu.many.domain.req.FenceSaveReq;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import lombok.AllArgsConstructor;
import lombok.experimental.SuperBuilder;
import io.swagger.annotations.*;
import com.muyu.common.core.annotation.Excel;
import com.muyu.common.core.web.domain.BaseEntity;

/**
 * 电子围栏对象 fence
 *
 * @author wan
 * @date 2024-06-17
 */
@Data
@SuperBuilder
@NoArgsConstructor
@AllArgsConstructor
@TableName("fence")
@EqualsAndHashCode(callSuper = true)
@ApiModel(value = "Fence", description = "电子围栏")
public class Fence extends BaseEntity {

    private static final long serialVersionUID = 1L;

    /** 主键 */
    @TableId(value = "id",type = IdType.AUTO)
    @ApiModelProperty(name = "主键", value = "主键")
    private Long id;

    /** 围栏名称 */
    @Excel(name = "围栏名称")
    @ApiModelProperty(name = "围栏名称", value = "围栏名称")
    private String fenceName;

    /** 围栏组ID */
    @Excel(name = "围栏组ID")
    @ApiModelProperty(name = "围栏组ID", value = "围栏组ID")
    private Long groupId;

    /** 围栏经纬度 */
    @Excel(name = "围栏经纬度")
    @ApiModelProperty(name = "围栏经纬度", value = "围栏经纬度")
    private String longitudeAndLatitude;

    /** 围栏备注 */
    @Excel(name = "围栏备注")
    @ApiModelProperty(name = "围栏备注", value = "围栏备注")
    private String fenceNote;

    /** 半径 */
    @Excel(name = "半径")
    @ApiModelProperty(name = "半径", value = "半径")
    private BigDecimal radius;

    /** 驶入，驶出 */
    @Excel(name = "驶入，驶出")
    @ApiModelProperty(name = "驶入，驶出", value = "驶入，驶出")
    private String driveOutIn;

    /** 是否删除 */
    @Excel(name = "是否删除")
    @ApiModelProperty(name = "是否删除", value = "是否删除")
    private Long isDelete;

    /** 围栏状态 */
    @Excel(name = "围栏状态")
    @ApiModelProperty(name = "围栏状态", value = "围栏状态")
    private Long fenceState;

    /**
    * 查询构造器
    */
    public static Fence queryBuild( FenceQueryReq fenceQueryReq){
        return Fence.builder()
                .fenceName(fenceQueryReq.getFenceName())
                .groupId(fenceQueryReq.getGroupId())
                .longitudeAndLatitude(fenceQueryReq.getLongitudeAndLatitude())
                .fenceNote(fenceQueryReq.getFenceNote())
                .radius(fenceQueryReq.getRadius())
                .driveOutIn(fenceQueryReq.getDriveOutIn())
                .isDelete(fenceQueryReq.getIsDelete())
                .fenceState(fenceQueryReq.getFenceState())
                .build();
    }

    /**
    * 添加构造器
    */
    public static Fence saveBuild(FenceSaveReq fenceSaveReq){
        return Fence.builder()
                .fenceName(fenceSaveReq.getFenceName())
                .groupId(fenceSaveReq.getGroupId())
                .longitudeAndLatitude(fenceSaveReq.getLongitudeAndLatitude())
                .fenceNote(fenceSaveReq.getFenceNote())
                .radius(fenceSaveReq.getRadius())
                .driveOutIn(fenceSaveReq.getDriveOutIn())
                .isDelete(fenceSaveReq.getIsDelete())
                .fenceState(fenceSaveReq.getFenceState())
                .build();
    }

    /**
    * 修改构造器
    */
    public static Fence editBuild(Long id, FenceEditReq fenceEditReq){
        return Fence.builder()
            .id(id)
                .fenceName(fenceEditReq.getFenceName())
                .groupId(fenceEditReq.getGroupId())
                .longitudeAndLatitude(fenceEditReq.getLongitudeAndLatitude())
                .fenceNote(fenceEditReq.getFenceNote())
                .radius(fenceEditReq.getRadius())
                .driveOutIn(fenceEditReq.getDriveOutIn())
                .isDelete(fenceEditReq.getIsDelete())
                .fenceState(fenceEditReq.getFenceState())
                .build();
    }

}
