package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.DefectInfoService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.many.domain.DefectInfo;
import com.muyu.many.domain.req.DefectInfoQueryReq;
import com.muyu.many.domain.req.DefectInfoSaveReq;
import com.muyu.many.domain.req.DefectInfoEditReq;
import com.muyu.common.core.web.page.TableDataInfo;

/**
 * 故障码Controller
 *
 * @author wan
 * @date 2024-06-20
 */
@Api(tags = "故障码")
@RestController
@RequestMapping("/defect")
public class DefectInfoController extends BaseController {
    @Autowired
    private DefectInfoService defectInfoService;

    /**
     * 查询故障码列表
     */
    @ApiOperation("获取故障码列表")
    @GetMapping("/list")
    public Result<TableDataInfo<DefectInfo>> list(DefectInfoQueryReq defectInfoQueryReq) {
        startPage();
        List<DefectInfo> list = defectInfoService.list(DefectInfo.queryBuild(defectInfoQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出故障码列表
     */
    @ApiOperation("导出故障码列表")
    @Log(title = "故障码", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DefectInfo defectInfo) {
        List<DefectInfo> list = defectInfoService.list(defectInfo);
        ExcelUtil<DefectInfo> util = new ExcelUtil<DefectInfo>(DefectInfo.class);
        util.exportExcel(response, list, "故障码数据");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }

    /**
     * 获取故障码详细信息
     */
    @ApiOperation("获取故障码详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<DefectInfo> getInfo(@PathVariable("id") Long id) {
        DefectInfo byId = defectInfoService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增故障码
     */
    @Log(title = "故障码", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增故障码")
    public Result<String> add(@RequestBody DefectInfoSaveReq defectInfoSaveReq) {
        boolean save = defectInfoService.save(DefectInfo.saveBuild(defectInfoSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改故障码
     */
    @Log(title = "故障码", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改故障码")
    public Result<String> edit(@PathVariable Long id, @RequestBody DefectInfoEditReq defectInfoEditReq) {
        boolean b = defectInfoService.updateById(DefectInfo.editBuild(id, defectInfoEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除故障码
     */
    @Log(title = "故障码", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除故障码")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = defectInfoService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }
}
