package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.FaultInfoService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.many.domain.DefectInfo;
import com.muyu.many.domain.FaultInfo;
import com.muyu.many.domain.req.DefectInfoAndFaultInfoList;
import com.muyu.many.domain.req.FaultInfoEditReq;
import com.muyu.many.domain.req.FaultInfoQueryReq;
import com.muyu.many.domain.req.FaultInfoSaveReq;
import com.muyu.many.domain.vo.FaultInfoVo;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;

/**
 * 故障记录Controller
 *
 * @author wan
 * @date 2024-06-20
 */
@Api(tags = "故障记录")
@RestController
@RequestMapping("/fault")
public class FaultInfoController extends BaseController {
    @Autowired
    private FaultInfoService faultInfoService;

    /**
     * 查询故障记录列表
     */
    @ApiOperation("获取故障记录列表")
    @GetMapping("/list")
    public Result<TableDataInfo<FaultInfo>> list(FaultInfoQueryReq faultInfoQueryReq) {
        startPage();
        List<FaultInfo> list = faultInfoService.list(FaultInfo.queryBuild(faultInfoQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出故障记录列表
     */
    @ApiOperation("导出故障记录列表")
    @Log(title = "故障记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FaultInfo faultInfo) {
        List<FaultInfo> list = faultInfoService.list(faultInfo);
        ExcelUtil<FaultInfo> util = new ExcelUtil<FaultInfo>(FaultInfo.class);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        util.exportExcel(response, list, "故障记录数据");
    }

    /**
     * 获取故障记录详细信息
     */
    @ApiOperation("获取故障记录详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<FaultInfo> getInfo(@PathVariable("id") Long id) {
        FaultInfo byId = faultInfoService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增故障记录
     */
    @Log(title = "故障记录", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增故障记录")
    public Result<String> add(@RequestBody FaultInfoSaveReq faultInfoSaveReq) {
        boolean save = faultInfoService.save(FaultInfo.saveBuild(faultInfoSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改故障记录
     */
    @Log(title = "故障记录", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改故障记录")
    public Result<String> edit(@PathVariable Long id, @RequestBody FaultInfoEditReq faultInfoEditReq) {
        boolean b = faultInfoService.updateById(FaultInfo.editBuild(id, faultInfoEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除故障记录
     */
    @Log(title = "故障记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除故障记录")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = faultInfoService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }


    @PostMapping("/statistics")
    public Result<List<DefectInfoAndFaultInfoList>> getDefectInfoAndFaultInfoList(@RequestBody FaultInfoVo faultInfoVo){
        return Result.success(
                faultInfoService.getDefectInfoAndFaultInfoList(faultInfoVo)
        );
    }
}
