package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.FenceService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.many.domain.Fence;
import com.muyu.many.domain.req.FenceEditReq;
import com.muyu.many.domain.req.FenceQueryReq;
import com.muyu.many.domain.req.FenceSaveReq;
import com.muyu.many.domain.vo.FenceReq;
import io.swagger.annotations.*;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;


/**
 * 电子围栏Controller
 *
 * @author wan
 * @date 2024-06-17
 */
@Api(tags = "电子围栏")
@RestController
@RequestMapping("/fence")
@Log4j2
public class FenceController extends BaseController {
    @Autowired
    private FenceService fenceService;

    /**
     * 查询电子围栏列表
     */
    @ApiOperation("获取电子围栏列表")
    @GetMapping("/list")
    public Result<TableDataInfo<Fence>> list(FenceQueryReq fenceQueryReq) {
        startPage();
        List<Fence> list = fenceService.list(Fence.queryBuild(fenceQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出电子围栏列表
     */
    @ApiOperation("导出电子围栏列表")
    @Log(title = "电子围栏", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Fence fence) {
        List<Fence> list = fenceService.list(fence);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        ExcelUtil<Fence> util = new ExcelUtil<Fence>(Fence.class);
        util.exportExcel(response, list, "电子围栏数据");
    }

    /**
     * 获取电子围栏详细信息
     */
    @ApiOperation("获取电子围栏详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Fence> getInfo(@PathVariable("id") Long id) {
        Fence byId = fenceService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增电子围栏
     */
    @Log(title = "电子围栏", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增电子围栏")
    public Result<String> add(@RequestBody FenceSaveReq fenceSaveReq) {
        boolean save = fenceService.save(Fence.saveBuild(fenceSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改电子围栏
     */
    @Log(title = "电子围栏", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改电子围栏")
    public Result<String> edit(@PathVariable Long id, @RequestBody FenceEditReq fenceEditReq) {
        boolean b = fenceService.updateById(Fence.editBuild(id, fenceEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除电子围栏
     */
    @Log(title = "电子围栏", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除电子围栏")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = fenceService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    @PostMapping("/IdAdd")
    public Result<String> IdAdd(@RequestBody FenceReq fenceReq){
        log.info(fenceReq);
        return fenceService.IdAdd(fenceReq);
    }
}
