package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.GroupService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.many.domain.Group;
import com.muyu.many.domain.req.GroupEditReq;
import com.muyu.many.domain.req.GroupQueryReq;
import com.muyu.many.domain.req.GroupSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;


/**
 * 围栏组Controller
 *
 * @author wan
 * @date 2024-06-17
 */
@Api(tags = "围栏组")
@RestController
@RequestMapping("/group")
public class GroupController extends BaseController {
    @Autowired
    private GroupService groupService;

    /**
     * 查询围栏组列表
     */
    @ApiOperation("获取围栏组列表")
    @GetMapping("/list")
    public Result<TableDataInfo<Group>> list(GroupQueryReq groupQueryReq) {
        startPage();
        List<Group> list = groupService.list(Group.queryBuild(groupQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出围栏组列表
     */
    @ApiOperation("导出围栏组列表")
    @Log(title = "围栏组", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Group group) {
        List<Group> list = groupService.list(group);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        ExcelUtil<Group> util = new ExcelUtil<Group>(Group.class);
        util.exportExcel(response, list, "围栏组数据");
    }

    /**
     * 获取围栏组详细信息
     */
    @ApiOperation("获取围栏组详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Group> getInfo(@PathVariable("id") Long id) {
        Group byId = groupService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增围栏组
     */
    @Log(title = "围栏组", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增围栏组")
    public Result<String> add(@RequestBody GroupSaveReq groupSaveReq) {
        boolean save = groupService.save(Group.saveBuild(groupSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改围栏组
     */
    @Log(title = "围栏组", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改围栏组")
    public Result<String> edit(@PathVariable Long id, @RequestBody GroupEditReq groupEditReq) {
        boolean b = groupService.updateById(Group.editBuild(id, groupEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除围栏组
     */
    @Log(title = "围栏组", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除围栏组")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = groupService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }
}
