package com.muyu.authentication.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.muyu.authentication.service.VehicleService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.utils.poi.ExcelUtil;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.many.domain.Vehicle;
import com.muyu.many.domain.req.VehicleEditReq;
import com.muyu.many.domain.req.VehicleQueryReq;
import com.muyu.many.domain.req.VehicleSaveReq;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;


/**
 * 车辆Controller
 *
 * @author wan
 * @date 2024-06-17
 */
@Api(tags = "车辆")
@RestController
@RequestMapping("/vehicle")
public class VehicleController extends BaseController {
    @Autowired
    private VehicleService vehicleService;

    /**
     * 查询车辆列表
     */
    @ApiOperation("获取车辆列表")
    @GetMapping("/list")
    public Result<TableDataInfo<Vehicle>> list(VehicleQueryReq vehicleQueryReq) {
        startPage();
        List<Vehicle> list = vehicleService.list(Vehicle.queryBuild(vehicleQueryReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return getDataTable(list);
    }

    /**
     * 导出车辆列表
     */
    @ApiOperation("导出车辆列表")
    @Log(title = "车辆", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Vehicle vehicle) {
        List<Vehicle> list = vehicleService.list(vehicle);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        ExcelUtil<Vehicle> util = new ExcelUtil<Vehicle>(Vehicle.class);
        util.exportExcel(response, list, "车辆数据");
    }

    /**
     * 获取车辆详细信息
     */
    @ApiOperation("获取车辆详细信息")
    @GetMapping(value = "/{id}")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<Vehicle> getInfo(@PathVariable("id") Long id) {
        Vehicle byId = vehicleService.getById(id);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return Result.success(byId);
    }

    /**
     * 新增车辆
     */
    @Log(title = "车辆", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增车辆")
    public Result<String> add(@RequestBody VehicleSaveReq vehicleSaveReq) {
        boolean save = vehicleService.save(Vehicle.saveBuild(vehicleSaveReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(save);
    }

    /**
     * 修改车辆
     */
    @Log(title = "车辆", businessType = BusinessType.UPDATE)
    @PutMapping("/{id}")
    @ApiOperation("修改车辆")
    public Result<String> edit(@PathVariable Long id, @RequestBody VehicleEditReq vehicleEditReq) {
        boolean b = vehicleService.updateById(Vehicle.editBuild(id, vehicleEditReq));
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }

    /**
     * 删除车辆
     */
    @Log(title = "车辆", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    @ApiOperation("删除车辆")
    @ApiImplicitParam(name = "id", value = "id", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> ids) {
        boolean b = vehicleService.removeBatchByIds(ids);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return toAjax(b);
    }
}
