package com.muyu.authentication.rabbitmq.vo;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.muyu.authentication.mapper.FaultInfoMapper;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.many.domain.Enterprise;
import com.muyu.many.domain.FaultInfo;
import lombok.extern.log4j.Log4j2;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;

/**
 * 接收故障信息
 *
 * @ClassName BreakdownAbnormalMq
 * @Author AnNan.Wang
 * @Date 2024/6/20 16:00
 */

@Log4j2
@Component
public class BreakdownAbnormalMq {


    @Autowired
    private FaultInfoMapper faultInfoMapper;
    @Autowired
    private StringRedisTemplate redisTemplate;

    @RabbitListener(queues = "discover_time")
    public void discoverTime(String message){
        log.info("开始消费");
        //转换
        FaultInfo faultInfo = JSON.parseObject(message, FaultInfo.class);

        log.info("faultInfo:{}", faultInfo);

        String key=faultInfo.getVin()+"123";
        String ent = redisTemplate.opsForValue().get(key);
        DynamicDataSourceHolder.setDynamicDataSourceKey(ent);
        faultInfoMapper.insert(faultInfo);
        log.info("消费结束");
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
    }


    @RabbitListener(queues = "resolve_time")
    public void resolveTime(String message){
        log.info("开始消费");
        FaultInfo faultInfo = JSON.parseObject(message, FaultInfo.class);
        log.info("faultInfo:{}", faultInfo);
        String[] split = faultInfo.getVin().split("-");
        log.info("split:{}",split[0]);

        FaultInfo build = FaultInfo.builder()
                .faultCode(split[1])
                .vin(split[0])
                .endTime(faultInfo.getEndTime())
                .build();
        String key=build.getVin()+"123";
        String ent = redisTemplate.opsForValue().get(key);
        DynamicDataSourceHolder.setDynamicDataSourceKey(ent);

        //获取最新一天数据
        List<FaultInfo> faultInfos = faultInfoMapper.selectList(
                new QueryWrapper<FaultInfo>()
                        .eq("fault_code", build.getFaultCode())  // 替换 yourFaultCode 为实际的故障代码值
                        .orderByDesc("start_time")
                        .last("LIMIT 1")
        );
        //判断非空
        if (!faultInfos.isEmpty()) {
            //获取第一条数据
            FaultInfo latestFaultInfo = faultInfos.get(0);
            // 这里可以对 latestFaultInfo 进行进一步操作或者返回
            log.info("Latest FaultInfo: {}", latestFaultInfo);

            //修改数据
            faultInfoMapper.updateById(
                    FaultInfo.builder()
                            .id(latestFaultInfo.getId())
                            .endTime(new Date())
                            .build()
            );
            DynamicDataSourceHolder.removeDynamicDataSourceKey();
            log.info("消费结束");
        }
        log.info("消费结束");
    }
}
