package com.muyu.authentication.service.impl;

import java.util.ArrayList;
import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.authentication.mapper.FaultInfoMapper;
import com.muyu.authentication.service.FaultInfoService;
import com.muyu.clw.common.many.datasource.holder.DynamicDataSourceHolder;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.many.domain.FaultInfo;
import com.muyu.many.domain.req.DefectInfoAndFaultInfoList;
import com.muyu.many.domain.vo.FaultInfoVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

/**
 * 故障记录Service业务层处理
 *
 * @author wan
 * @date 2024-06-20
 */
@Slf4j
@Service
public class FaultInfoServiceImpl extends ServiceImpl<FaultInfoMapper, FaultInfo> implements FaultInfoService {

    @Autowired
    private FaultInfoMapper faultInfoMapper;

    /**
     * 查询故障记录列表
     *
     * @param faultInfo 故障记录
     * @return 故障记录
     */
    @Override
    public List<FaultInfo> list(FaultInfo faultInfo) {
        LambdaQueryWrapper<FaultInfo> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(faultInfo.getFaultCode())){
            queryWrapper.eq(FaultInfo::getFaultCode, faultInfo.getFaultCode());
        }

        if (ObjUtils.notNull(faultInfo.getVin())){
            queryWrapper.eq(FaultInfo::getVin, faultInfo.getVin());
        }

        if (ObjUtils.notNull(faultInfo.getFailureLevel())){
            queryWrapper.eq(FaultInfo::getFailureLevel, faultInfo.getFailureLevel());
        }

        if (ObjUtils.notNull(faultInfo.getStartTime())){
            queryWrapper.eq(FaultInfo::getStartTime, faultInfo.getStartTime());
        }

        if (ObjUtils.notNull(faultInfo.getEndTime())){
            queryWrapper.eq(FaultInfo::getEndTime, faultInfo.getEndTime());
        }
        return list(queryWrapper);
    }


    @Override
    public List<DefectInfoAndFaultInfoList> getDefectInfoAndFaultInfoList(FaultInfoVo faultInfoVo) {
        List<DefectInfoAndFaultInfoList> defectInfoAndFaultInfoList = faultInfoMapper.getDefectInfoAndFaultInfoList(faultInfoVo);
        DynamicDataSourceHolder.removeDynamicDataSourceKey();
        return defectInfoAndFaultInfoList;
    }
}
