package com.muyu.authentication.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.authentication.mapper.FenceMapper;
import com.muyu.authentication.service.FenceService;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.utils.ObjUtils;
import com.muyu.many.domain.Fence;
import com.muyu.many.domain.vo.FenceReq;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 电子围栏Service业务层处理
 *
 * @author wan
 * @date 2024-06-17
 */
@Slf4j
@Service
public class FenceServiceImpl extends ServiceImpl<FenceMapper, Fence> implements FenceService {

    /**
     * 查询电子围栏列表
     *
     * @param fence 电子围栏
     * @return 电子围栏
     */
    @Override
    public List<Fence> list(Fence fence) {

        LambdaQueryWrapper<Fence> queryWrapper = new LambdaQueryWrapper<>();


        if (ObjUtils.notNull(fence.getFenceName())){
            queryWrapper.like(Fence::getFenceName, fence.getFenceName());
        }

        if (ObjUtils.notNull(fence.getGroupId())){
            queryWrapper.eq(Fence::getGroupId, fence.getGroupId());
        }

        if (ObjUtils.notNull(fence.getLongitudeAndLatitude())){
            queryWrapper.eq(Fence::getLongitudeAndLatitude, fence.getLongitudeAndLatitude());
        }

        if (ObjUtils.notNull(fence.getFenceNote())){
            queryWrapper.eq(Fence::getFenceNote, fence.getFenceNote());
        }

        if (ObjUtils.notNull(fence.getRadius())){
            queryWrapper.eq(Fence::getRadius, fence.getRadius());
        }

        if (ObjUtils.notNull(fence.getDriveOutIn())){
            queryWrapper.eq(Fence::getDriveOutIn, fence.getDriveOutIn());
        }

        if (ObjUtils.notNull(fence.getIsDelete())){
            queryWrapper.eq(Fence::getIsDelete, fence.getIsDelete());
        }

        if (ObjUtils.notNull(fence.getFenceState())){
            queryWrapper.eq(Fence::getFenceState, fence.getFenceState());
        }


        return list(queryWrapper);
    }


    @Override
    public Result<String> IdAdd(FenceReq fenceReq) {
        boolean b = this.updateById(
                Fence.builder()
                        .id(fenceReq.getId())
                        .longitudeAndLatitude(String.valueOf(fenceReq.getLocationsList()))
                        .build()
        );
        return Result.success(b ? "修改成功" : "修改失败");
    }
}
